OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Yer İmleri",
    "Failed to import one bookmark, because: " : "Bir yer imi şu nedenle içe aktarılamadı:",
    "No file provided for import" : "İçe aktarılacak bir dosya seçilmemiş",
    "Unsupported file type for import" : "İçe aktarılacak dosya türü desteklenmiyor",
    "Add a Bookmark" : "Yer İmi Ekle",
    "Add folder" : "Klasör ekle",
    "Select" : "Seç",
    "Deselect" : "Bırak",
    "Details" : "Ayrıntılar",
    "Delete" : "Sil",
    "Saved" : "Kaydedildi",
    "Date added" : "Eklendiği tarih",
    "Link" : "Bağlantı",
    "Tags" : "İşaretler",
    "Description" : "Açıklama",
    "No bookmarks here." : "Henüz bir yer imi yok.",
    "Favorites" : "Sık Kullanılanlar",
    "Settings" : "Ayarlar",
    "Bookmarklet" : "Bookmarklet",
    "Add to {instanceName} " : "{instanceName} üzerine ekle  ",
    "Recently added" : "Son Eklenenler",
    "Most visited" : "En Çok Bakılanlar",
    "RSS Feed" : "RSS Akışı",
    "Permanently remove all bookmarks from your account. There is no going back!" : "Hesabınızdaki tüm yer imlerini kalıcı olarak siler. Bu işlem geri alınamaz!",
    "Delete all bookmarks" : "Tüm yer imlerini sil",
    "Open details" : "Ayrıntıları aç",
    "An error occurred while trying to save the bookmark." : "Yer imi kaydedilmeye çalışılırken bir sorun çıktı.",
    "Error" : "Hata",
    "Uncategorized" : "Kategorisiz",
    "Error parsing the import result" : "İçe aktarma sonuçları işlenirken sorun çıktı",
    "Import completed successfully." : "İçe aktarma tamamlandı.",
    "Do you really want to delete all your bookmarks?" : "Tüm yer imlerinizi silmek istediğinize emin misiniz?",
    "Set tags" : "Etiketleri ayarla",
    "A Bookmark manager for Nextcloud" : "Nextcloud için yer imi yöneticisi",
    "This app allows you to store and organize your favorite places on the web in one spot, while allowing you to sync them with your various devices and browsers.\nCheck out the third-party clients listed here: https://github.com/nextcloud/bookmarks#third-party-clients" : "Bu uygulama İnternet üzerinde sık ziyaret ettiğiniz konumları bir noktada toplamanızı ve farklı aygıt ve tarayıcılar ile eşitlemenizi sağlar.\nÜçüncü taraf istemcileri şurada görebilirsiniz: https://github.com/nextcloud/bookmarks#third-party-clients",
    "Add a bookmark" : "Yer imi ekle",
    "This URL is already bookmarked! Overwrite?" : "Bu adres zaten yer imlerine eklenmiş! Üzerine yazılsın mı?",
    "The title of the page" : "Sayfa başlığı",
    "The address of the page" : "Sayfa adresi",
    "Description of the page" : "Sayfa açıklaması",
    "Save" : "Kaydet",
    "Previews" : "Önizlemeler",
    "In order to display real screenshots of your bookmarked websites, Bookmarks can use a third-party service to generate those." : "Yer imlerine eklediğiniz web sitelerinin gerçek ekran görüntülerinin görüntülenmesi için Yer İmleri uygulaması üçüncü taraf bir hizmet kullanabilir.",
    "You can either sign up for free at <a href=\"http://screeenly.com\">screeenly.com</a> or <a href=\"https://github.com/stefanzweifel/screeenly\">setup your own server</a>." : "<a href=\"http://screeenly.com\">screeenly.com</a> üzerinde ücretsiz bir hesap açabilir ya da <a href=\"https://github.com/stefanzweifel/screeenly\">kendi sunucunuzu kurabilirsiniz</a>.",
    "Screenly API URL" : "Screenly API Adresi",
    "Screenly API key" : "Screenly API Anahtarı",
    "Bookmarks feed" : "Yer imleri akışı"
},
"nplurals=2; plural=(n > 1);");
